==> kmyfirewall_1.0.orig.tar.gz: kmyfirewall-1.0/kmyfirewall/ruleoptionplugins/log_target_option/kmfruleedittargetlog.h <==
/***************************************************************************
 begin                : Wed May 22 2002
 copyright            : (C) 2002 by Christian Hubinger
 email                : chubinger@gmail.com
***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef KMFRULEEDITTARGETLOG_H
#define KMFRULEEDITTARGETLOG_H
#include "kmyfirewallruleeditortargetlog.h"

#include <qwidget.h>
#include <qptrlist.h>

class IPTRule;
/**
  *@author Christian Hubinger
  */

class KMFRuleEditTargetLog : public KMyFirewallRuleEditorTargetLog {
	Q_OBJECT
public:
	KMFRuleEditTargetLog( QWidget *parent = 0, const char *name = 0, WFlags fl = 0 );
	~KMFRuleEditTargetLog();

	QPtrList<QString>* options;

	void loadRule( IPTRule * );
public slots:
	void accept();
	void slotHelp();
	void reject();

private:
	IPTRule* m_rule;

signals:
	void sigAddTargetOpt( QString*, QPtrList<QString>* );
	void sigDocumentChanged();
	void sigHideMe();
};

#endif

==> kmyfirewall_1.1.1.orig.tar.gz: kmyfirewall-1.1.1/kmyfirewall/ruleoptionplugins/log_target_option/kmfruleedittargetlog.h <==
/***************************************************************************
 begin                : Wed May 22 2002
 copyright            : (C) 2002 by Christian Hubinger
 email                : chubinger@irrsinnig.org
***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef KMFRULEEDITTARGETLOG_H
#define KMFRULEEDITTARGETLOG_H
#include "kmyfirewallruleeditortargetlog.h"

#include <qwidget.h>
#include <qptrlist.h>
namespace KMF {
class IPTRule;
/**
  *@author Christian Hubinger
  */

class KMFRuleEditTargetLog : public KMyFirewallRuleEditorTargetLog {
	Q_OBJECT
public:
	KMFRuleEditTargetLog( QWidget *parent = 0, const char *name = 0, WFlags fl = 0 );
	~KMFRuleEditTargetLog();

	QPtrList<QString>* options;

	void loadRule( IPTRule * );
public slots:
	void accept();
	void slotHelp();
	void reject();

private:
	IPTRule* m_rule;

signals:
/*	void sigAddRuleOpt( QString*, QPtrList<QString>* );
	void sigAddTargetOpt( QString*, QPtrList<QString>* );*/
	void sigDocumentChanged();
	void sigHideMe();
};
}
#endif
